@@ -55,6 +55,7 @@ except ImportError:
     pass
 
 from . import matchers
+from .py37compat import best_realpath
 
 
 __all__ = ['Path', 'TempDir', 'CaseInsensitivePattern']
@@ -69,15 +70,15 @@ U_NL_END = re.compile(r'(?:{0})$'.format(U_NEWLINE.pattern))
 
 
 try:
-    from importlib import metadata
+    from importlib import metadata  # type: ignore
 except ImportError:
     try:
-        import importlib_metadata as metadata
+        import importlib_metadata as metadata  # type: ignore
     except ImportError:
         pass
 
 try:
-    __version__ = metadata.version('path')
+    __version__ = metadata.version('path')  # type: ignore
 except Exception:
     __version__ = 'unknown'
 
@@ -253,7 +254,8 @@ class Path(str):
 
     def realpath(self):
         """ .. seealso:: :func:`os.path.realpath` """
-        return self._next_class(self.module.realpath(self))
+        realpath = best_realpath(self.module)
+        return self._next_class(realpath(self))
 
     def expanduser(self):
         """ .. seealso:: :func:`os.path.expanduser` """
@@ -818,7 +820,8 @@ class Path(str):
 
         .. seealso:: :meth:`text`
         """
-        return self.text(encoding, errors).splitlines(retain)
+        text = U_NEWLINE.sub('\n', self.read_text(encoding, errors))
+        return text.splitlines(retain)
 
     def write_lines(
         self, lines, encoding=None, errors='strict', linesep=os.linesep, append=False
