@@ -13,7 +13,7 @@ seconds to allow some time to pass between calls to check the modify
 time on files.
 """
 
-import codecs
+import io
 import os
 import sys
 import shutil
@@ -538,7 +538,7 @@ class TestScratchDir:
         )
         if hasattr(os, 'symlink'):
             assert testCopyOfLink.islink()
-            assert testCopyOfLink.readlink() == testFile
+            assert testCopyOfLink.realpath() == testFile
 
         # Clean up.
         testDir.rmtree()
@@ -569,7 +569,6 @@ class TestScratchDir:
         self.assertList(d.walkfiles('*.tmp'), [e / 'x.tmp' for e in dirs])
         self.assertList(d.walkdirs('*.tmp'), [d / 'xdir.tmp'])
 
-    @pytest.mark.filterwarnings("ignore:.text is deprecated")
     @pytest.mark.parametrize("encoding", ('UTF-8', 'UTF-16BE', 'UTF-16LE', 'UTF-16'))
     def test_unicode(self, tmpdir, encoding):
         """ Test that path works with the specified encoding,
@@ -579,58 +578,37 @@ class TestScratchDir:
         d = Path(tmpdir)
         p = d / 'unicode.txt'
 
-        given = (
-            'Hello world\n'
-            '\u0d0a\u0a0d\u0d15\u0a15\r\n'
-            '\u0d0a\u0a0d\u0d15\u0a15\x85'
-            '\u0d0a\u0a0d\u0d15\u0a15\u2028'
-            '\r'
-            'hanging'
-        )
-        clean = (
-            'Hello world\n'
-            '\u0d0a\u0a0d\u0d15\u0a15\n'
-            '\u0d0a\u0a0d\u0d15\u0a15\n'
-            '\u0d0a\u0a0d\u0d15\u0a15\n'
-            '\n'
-            'hanging'
-        )
         givenLines = [
-            ('Hello world\n'),
-            ('\u0d0a\u0a0d\u0d15\u0a15\r\n'),
-            ('\u0d0a\u0a0d\u0d15\u0a15\x85'),
-            ('\u0d0a\u0a0d\u0d15\u0a15\u2028'),
-            ('\r'),
-            ('hanging'),
+            'Hello world\n',
+            '\u0d0a\u0a0d\u0d15\u0a15\r\n',
+            '\u0d0a\u0a0d\u0d15\u0a15\x85',
+            '\u0d0a\u0a0d\u0d15\u0a15\u2028',
+            '\r',
+            'hanging',
         ]
+        given = ''.join(givenLines)
         expectedLines = [
-            ('Hello world\n'),
-            ('\u0d0a\u0a0d\u0d15\u0a15\n'),
-            ('\u0d0a\u0a0d\u0d15\u0a15\n'),
-            ('\u0d0a\u0a0d\u0d15\u0a15\n'),
-            ('\n'),
-            ('hanging'),
-        ]
-        expectedLines2 = [
-            ('Hello world'),
-            ('\u0d0a\u0a0d\u0d15\u0a15'),
-            ('\u0d0a\u0a0d\u0d15\u0a15'),
-            ('\u0d0a\u0a0d\u0d15\u0a15'),
-            (''),
-            ('hanging'),
+            'Hello world\n',
+            '\u0d0a\u0a0d\u0d15\u0a15\n',
+            '\u0d0a\u0a0d\u0d15\u0a15\n',
+            '\u0d0a\u0a0d\u0d15\u0a15\n',
+            '\n',
+            'hanging',
         ]
+        clean = ''.join(expectedLines)
+        stripped = [line.replace('\n', '') for line in expectedLines]
 
         # write bytes manually to file
-        f = codecs.open(p, 'w', encoding)
-        f.write(given)
-        f.close()
+        with io.open(p, 'wb') as strm:
+            strm.write(given.encode(encoding))
 
         # test all 3 path read-fully functions, including
         # path.lines() in unicode mode.
         assert p.bytes() == given.encode(encoding)
-        assert p.text(encoding) == clean
+        with pytest.deprecated_call():
+            assert p.text(encoding) == clean
         assert p.lines(encoding) == expectedLines
-        assert p.lines(encoding, retain=False) == expectedLines2
+        assert p.lines(encoding, retain=False) == stripped
 
         # If this is UTF-16, that's enough.
         # The rest of these will unfortunately fail because append=True
@@ -650,14 +628,15 @@ class TestScratchDir:
         expectedLinesNoHanging = expectedLines[:]
         expectedLinesNoHanging[-1] += '\n'
         assert p.bytes() == expectedBytes
-        assert p.text(encoding) == 2 * cleanNoHanging
+        with pytest.deprecated_call():
+            assert p.text(encoding) == 2 * cleanNoHanging
         assert p.lines(encoding) == 2 * expectedLinesNoHanging
-        assert p.lines(encoding, retain=False) == 2 * expectedLines2
+        assert p.lines(encoding, retain=False) == 2 * stripped
 
         # Write Unicode to file using path.write_lines().
         # The output in the file should be exactly the same as last time.
         p.write_lines(expectedLines, encoding)
-        p.write_lines(expectedLines2, encoding, append=True)
+        p.write_lines(stripped, encoding, append=True)
         # Check the result.
         assert p.bytes() == expectedBytes
 
@@ -688,7 +667,8 @@ class TestScratchDir:
         # Check the result.
         expectedBytes = 2 * given.encode(encoding)
         assert p.bytes() == expectedBytes
-        assert p.text(encoding) == 2 * clean
+        with pytest.deprecated_call():
+            assert p.text(encoding) == 2 * clean
         expectedResultLines = expectedLines[:]
         expectedResultLines[-1] += expectedLines[0]
         expectedResultLines += expectedLines[1:]
